pub struct OpenResponseError { /* private fields */ }Expand description
Structured error object for Open Responses.
Errors are designed to provide clear, actionable feedback with machine-readable types and codes alongside human-readable messages.
Implementations
Sourceimpl OpenResponseError
impl OpenResponseError
Sourcepub fn invalid_request(message: impl Into<String>) -> Self
pub fn invalid_request(message: impl Into<String>) -> Self
Creates an invalid request error.
Sourcepub fn invalid_param(
param: impl Into<String>,
message: impl Into<String>,
) -> Self
pub fn invalid_param( param: impl Into<String>, message: impl Into<String>, ) -> Self
Creates an invalid request error with a parameter reference.
Sourcepub fn rate_limit(message: impl Into<String>) -> Self
pub fn rate_limit(message: impl Into<String>) -> Self
Creates a rate limit error.
Sourcepub fn with_code(self, code: OpenResponseErrorCode) -> Self
pub fn with_code(self, code: OpenResponseErrorCode) -> Self
Sets the error code.
Sourcepub fn with_param(self, param: impl Into<String>) -> Self
pub fn with_param(self, param: impl Into<String>) -> Self
Sets the parameter reference.