pub struct ProviderConfig {
pub api_key: Option<String>,
pub openai_chatgpt_auth: Option<OpenAIChatGptAuthHandle>,
pub copilot_auth: Option<CopilotAuthConfig>,
pub base_url: Option<String>,
pub model: Option<String>,
pub prompt_cache: Option<PromptCachingConfig>,
pub timeouts: Option<TimeoutsConfig>,
pub openai: Option<OpenAIConfig>,
pub anthropic: Option<AnthropicConfig>,
pub model_behavior: Option<ModelConfig>,
pub workspace_root: Option<PathBuf>,
}Fields
api_key: Option<String>openai_chatgpt_auth: Option<OpenAIChatGptAuthHandle>copilot_auth: Option<CopilotAuthConfig>base_url: Option<String>model: Option<String>prompt_cache: Option<PromptCachingConfig>timeouts: Option<TimeoutsConfig>openai: Option<OpenAIConfig>anthropic: Option<AnthropicConfig>model_behavior: Option<ModelConfig>workspace_root: Option<PathBuf>Trait Implementations
Sourceimpl Clone for ProviderConfig
impl Clone for ProviderConfig
Sourceimpl Debug for ProviderConfig
impl Debug for ProviderConfig
Sourceimpl ProviderConfig for ProviderConfig
ProviderConfig implementation for the concrete factory configuration.
impl ProviderConfig for ProviderConfig
ProviderConfig implementation for the concrete factory configuration.
Sourcefn api_key(&self) -> Option<Cow<'_, str>>
fn api_key(&self) -> Option<Cow<'_, str>>
API key or bearer token used to authenticate with the provider.
Sourcefn prompt_cache(&self) -> Option<Cow<'_, PromptCachingConfig>>
fn prompt_cache(&self) -> Option<Cow<'_, PromptCachingConfig>>
Optional prompt cache configuration forwarded to providers that support
caching.
Sourcefn timeouts(&self) -> Option<Cow<'_, TimeoutsConfig>>
fn timeouts(&self) -> Option<Cow<'_, TimeoutsConfig>>
Optional request timeout configuration forwarded to the provider factory.
Sourcefn openai(&self) -> Option<Cow<'_, OpenAIConfig>>
fn openai(&self) -> Option<Cow<'_, OpenAIConfig>>
Optional OpenAI-specific configuration forwarded to the provider factory.
Sourcefn anthropic(&self) -> Option<Cow<'_, AnthropicConfig>>
fn anthropic(&self) -> Option<Cow<'_, AnthropicConfig>>
Optional Anthropic-specific configuration forwarded to the provider factory.
Sourcefn model_behavior(&self) -> Option<Cow<'_, ModelConfig>>
fn model_behavior(&self) -> Option<Cow<'_, ModelConfig>>
Optional model behavior configuration (loop detection, capability overrides).