pub enum AnthropicContentBlock {
Show 17 variants
Text {
text: String,
citations: Option<Vec<TextCitation>>,
cache_control: Option<CacheControl>,
},
Image {
source: ImageSource,
cache_control: Option<CacheControl>,
},
ToolUse(Box<AnthropicToolUseBlock>),
ToolResult(Box<AnthropicToolResultBlock>),
Thinking {
thinking: String,
signature: Option<String>,
cache_control: Option<CacheControl>,
},
RedactedThinking {
data: String,
cache_control: Option<CacheControl>,
},
Compaction {
content: Option<String>,
signature: Option<String>,
cache_control: Option<CacheControl>,
extra: Map<String, Value>,
},
ServerToolUse {
id: String,
name: String,
input: Value,
},
ToolSearchToolResult {
tool_use_id: String,
content: ToolSearchResultContent,
},
ContainerUpload {
file_id: String,
},
CodeExecutionToolResult {
tool_use_id: String,
content: Value,
},
BashCodeExecutionToolResult {
tool_use_id: String,
content: Value,
},
TextEditorCodeExecutionToolResult {
tool_use_id: String,
content: Value,
},
WebSearchToolResult {
tool_use_id: String,
content: Value,
},
AdvisorToolResult {
tool_use_id: String,
content: Value,
},
Fallback {
from: AnthropicFallbackModel,
to: AnthropicFallbackModel,
},
Unknown,
}Variants
Text
Image
ToolUse(Box<AnthropicToolUseBlock>)
ToolResult(Box<AnthropicToolResultBlock>)
Thinking
RedactedThinking
Compaction
Fields
content: Option<String>Threshold compaction streams may start with null and provide the
summary in a single delta. On-demand compaction returns the full
signed block in the start event.
cache_control: Option<CacheControl>ServerToolUse
Server-side tool use (e.g., tool search execution) - advanced-tool-use beta
ToolSearchToolResult
Tool search result containing discovered tool references - advanced-tool-use beta
ContainerUpload
Files API upload reference used by Anthropic code execution.
CodeExecutionToolResult
Generic code execution result block used in some Anthropic responses.
BashCodeExecutionToolResult
Bash code execution result block returned by Anthropic code execution.
TextEditorCodeExecutionToolResult
Text editor code execution result block returned by Anthropic code execution.
WebSearchToolResult
Native web search result blocks returned by Anthropic web search tools.
AdvisorToolResult
Advisor tool result block returned by the server-side advisor sub-inference.
content is the verbatim result union (advisor_result,
advisor_redacted_result, or advisor_tool_result_error).
Fallback
Fallback content block marking model boundary in server-side fallback
Unknown
Catch-all for unknown content block types added by the Anthropic API.