Module types

Module types 

OpenResponses specification types.

This module defines types that conform to the OpenResponses specification. See https://www.openresponses.org/specification for details.

Structs

AssistantMessageItemParam
Assistant message item parameter.
DeveloperMessageItemParam
Developer message item parameter.
FunctionCallItemParam
Function call item parameter.
FunctionCallOutputItemParam
Function call output item parameter.
FunctionToolParam
Function tool parameter.
IncompleteDetails
Incomplete details for partial responses.
InputFileContent
Input file content.
InputImageContent
Input image content.
InputTextContent
Input text content for user/system/developer messages.
ItemReferenceParam
Item reference parameter for referencing previous items.
OpenResponsesResponse
OpenResponses API response body.
OutputTextContent
Output text content for assistant messages.
ReasoningItemParam
Reasoning item parameter.
ReasoningSummaryContent
Reasoning summary content.
ReasoningUsage
Usage information for reasoning items.
RefusalContent
Refusal content for when the model refuses a request.
ResponseError
Error object.
ResponseUsage
Response usage statistics.
SpecificFunctionChoice
Specific function choice.
SystemMessageItemParam
System message item parameter.
UserMessageItemParam
User message item parameter.

Enums

Annotation
Annotation for citations.
FunctionCallStatus
Status for function calls.
ImageDetail
Image detail level.
InputContent
Content part union for input messages.
ItemParam
Union of all item parameters that can be sent as input.
ItemStatus
Status for items that have a lifecycle.
ItemType
The type of an item in the OpenResponses API.
MessageRole
Role for message items.
OutputContent
Content part union for output messages.
ResponseStatus
Response status.
ToolChoiceParam
Tool choice parameter union.
ToolChoiceValue
Tool choice values.