vtcode-llm - LLM Provider Abstraction
Provides a unified interface for multiple LLM providers including Gemini, OpenAI, Anthropic, Meta AI, DeepSeek, and Ollama.
Re-exports
pub use capabilities::ProviderCapabilities;pub use client::AnyClient;pub use client::ProviderClientAdapter;pub use config_adapter::AdapterEvent;pub use config_adapter::AdapterHooks;pub use config_adapter::AdapterHooksProvider;pub use config_adapter::OwnedProviderConfig;pub use config_adapter::as_factory_config;pub use config_adapter::as_factory_config_with_hooks;pub use factory_types::ProviderConfig;pub use factory_types::infer_provider_from_model;pub use model_resolver::DynamicModelMeta;pub use model_resolver::DynamicModelRef;pub use model_resolver::ModelAvailability;pub use model_resolver::ModelResolver;pub use model_resolver::ResolvedModel;pub use provider::LLMStream;pub use provider::LLMStreamEvent;pub use provider_config_types::ProviderConfig as ProviderConfigData;pub use tool_bridge::CorrelationStats;pub use tool_bridge::IntentFulfillment;pub use tool_bridge::MessageCorrelationTracker;pub use tool_bridge::MessageToolCorrelation;pub use tool_bridge::ToolExecution;pub use tool_bridge::ToolIntent;pub use tool_bridge::ToolIntentExtractor;
Modules
- capabilities
- Compatibility re-export for provider capability metadata.
- client
- config_
adapter - Provider configuration traits decoupled from VT Code’s dot-config storage.
- copilot
- error_
display - LLM error display utilities with enhanced ANSI color support
- factory_
types - Core provider configuration type.
- http_
client - Centralized HTTP client factory for LLM providers.
- model_
resolver - open_
responses - Open Responses specification conformance layer.
- provider
- Universal LLM provider abstraction with API-specific role handling
- provider_
base - Base traits and utilities for LLM providers
- provider_
config_ types - Core provider configuration type.
- providers
- reasoning_
effort - Capability-driven reasoning validation before a provider request is sent.
- rig_
adapter - single_
response - tool_
bridge - Bridge between messages and tool executions
- types
- usage_
cost - Provider-normalized token usage and shared raw/cache-aware USD estimates.
- utils
- Shared utilities for LLM request/response processing
Macros
- delegate_
components - Wire multiple component names to provider types for a context.
Structs
- LLMResponse
- Universal LLM response structure
- Usage
Enums
- Backend
Kind - Finish
Reason - LLMError
- LLM error types with optional provider metadata